@@ -35,6 +35,12 @@ $ python setup.py help
      libraries=["milter","smutil","resolv"]
 
  * $Log: miltermodule.c,v $
+ * Revision 1.17  2009/02/06 04:28:08  customdesigned
+ * Oops!  Missing options argument pointer for addrcpt.
+ *
+ * Revision 1.16  2008/12/16 04:21:05  customdesigned
+ * Fedora release
+ *
  * Revision 1.15  2008/12/13 20:29:56  customdesigned
  * Split off milter applications.
  *
@@ -1097,7 +1103,7 @@ milter_addrcpt(PyObject *self, PyObject *args) {
   PyThreadState *t;
   int rc;
   
-  if (!PyArg_ParseTuple(args, "s|z:addrcpt", &rcpt)) return NULL;
+  if (!PyArg_ParseTuple(args, "s|z:addrcpt", &rcpt, &params)) return NULL;
   ctx = _find_context(self);
   if (ctx == NULL) return NULL;
   t = PyEval_SaveThread();
@@ -1149,8 +1155,8 @@ milter_replacebody(PyObject *self, PyObject *args) {
   ctx = _find_context(self);
   if (ctx == NULL) return NULL;
   t = PyEval_SaveThread();
-  return _thread_return(t,smfi_replacebody(ctx, bodyp, bodylen),
-			 "cannot replace message body");
+  return _thread_return(t,smfi_replacebody(ctx,
+	(unsigned char *)bodyp, bodylen), "cannot replace message body");
 }
 
 static char milter_setpriv__doc__[] =
